pub struct AnimationClient { /* private fields */ }Expand description
Client for Animation domain commands.
Implementations
Sourceimpl AnimationClient
impl AnimationClient
Sourcepub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Disables animation domain notifications.
Sourcepub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Enables animation domain notifications.
Sourcepub async fn get_current_time(
&self,
params: GetCurrentTimeParams,
session_id: Option<&str>,
) -> Result<GetCurrentTimeReturns, CdpError>
pub async fn get_current_time( &self, params: GetCurrentTimeParams, session_id: Option<&str>, ) -> Result<GetCurrentTimeReturns, CdpError>
Returns the current time of the an animation.
Sourcepub async fn get_playback_rate(
&self,
session_id: Option<&str>,
) -> Result<GetPlaybackRateReturns, CdpError>
pub async fn get_playback_rate( &self, session_id: Option<&str>, ) -> Result<GetPlaybackRateReturns, CdpError>
Gets the playback rate of the document timeline.
Sourcepub async fn release_animations(
&self,
params: ReleaseAnimationsParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn release_animations( &self, params: ReleaseAnimationsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Releases a set of animations to no longer be manipulated.
Sourcepub async fn resolve_animation(
&self,
params: ResolveAnimationParams,
session_id: Option<&str>,
) -> Result<ResolveAnimationReturns, CdpError>
pub async fn resolve_animation( &self, params: ResolveAnimationParams, session_id: Option<&str>, ) -> Result<ResolveAnimationReturns, CdpError>
Gets the remote object of the Animation.
Sourcepub async fn seek_animations(
&self,
params: SeekAnimationsParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn seek_animations( &self, params: SeekAnimationsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Seek a set of animations to a particular time within each animation.
Sourcepub async fn set_paused(
&self,
params: SetPausedParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_paused( &self, params: SetPausedParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Sets the paused state of a set of animations.
Sourcepub async fn set_playback_rate(
&self,
params: SetPlaybackRateParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_playback_rate( &self, params: SetPlaybackRateParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Sets the playback rate of the document timeline.
Sourcepub async fn set_timing(
&self,
params: SetTimingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_timing( &self, params: SetTimingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Sets the timing of an animation node.