BluetoothEmulationClient

Struct BluetoothEmulationClient 

pub struct BluetoothEmulationClient { /* private fields */ }
Client for BluetoothEmulation domain commands.

Implementations

Source

impl BluetoothEmulationClient

pub async fn enable( &self, params: EnableParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enable the BluetoothEmulation domain.

pub async fn set_simulated_central_state( &self, params: SetSimulatedCentralStateParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Set the state of the simulated central.

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Disable the BluetoothEmulation domain.

pub async fn simulate_preconnected_peripheral( &self, params: SimulatePreconnectedPeripheralParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates a peripheral with |address|, |name| and |knownServiceUuids| that has already been connected to the system.

pub async fn simulate_advertisement( &self, params: SimulateAdvertisementParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates an advertisement packet described in |entry| being received by the central.

pub async fn simulate_gatt_operation_response( &self, params: SimulateGattOperationResponseParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates the response code from the peripheral with |address| for a GATT operation of |type|. The |code| value follows the HCI Error Codes from Bluetooth Core Specification Vol 2 Part D 1.3 List Of Error Codes.

pub async fn simulate_characteristic_operation_response( &self, params: SimulateCharacteristicOperationResponseParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.

pub async fn simulate_descriptor_operation_response( &self, params: SimulateDescriptorOperationResponseParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.

pub async fn add_service( &self, params: AddServiceParams, session_id: Option<&str>, ) -> Result<AddServiceReturns, CdpError>

Adds a service with |serviceUuid| to the peripheral with |address|.

pub async fn remove_service( &self, params: RemoveServiceParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Removes the service respresented by |serviceId| from the simulated central.

pub async fn add_characteristic( &self, params: AddCharacteristicParams, session_id: Option<&str>, ) -> Result<AddCharacteristicReturns, CdpError>

Adds a characteristic with |characteristicUuid| and |properties| to the service represented by |serviceId|.

pub async fn remove_characteristic( &self, params: RemoveCharacteristicParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Removes the characteristic respresented by |characteristicId| from the simulated central.

pub async fn add_descriptor( &self, params: AddDescriptorParams, session_id: Option<&str>, ) -> Result<AddDescriptorReturns, CdpError>

Adds a descriptor with |descriptorUuid| to the characteristic respresented by |characteristicId|.

pub async fn remove_descriptor( &self, params: RemoveDescriptorParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Removes the descriptor with |descriptorId| from the simulated central.

pub async fn simulate_gatt_disconnection( &self, params: SimulateGattDisconnectionParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulates a GATT disconnection from the peripheral with |address|.