CastClient

Struct CastClient 

pub struct CastClient { /* private fields */ }
Client for Cast domain commands.

Implementations

Source

impl CastClient

pub async fn enable( &self, params: EnableParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Stops observing for sinks and issues.

pub async fn set_sink_to_use( &self, params: SetSinkToUseParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.

pub async fn start_desktop_mirroring( &self, params: StartDesktopMirroringParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Starts mirroring the desktop to the sink.

pub async fn start_tab_mirroring( &self, params: StartTabMirroringParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Starts mirroring the tab to the sink.

pub async fn stop_casting( &self, params: StopCastingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Stops the active Cast session on the sink.