pub struct CSSRegistration { /* private fields */ }Expand description
Event registration interface for CSS domain.
Implementations
Sourceimpl CSSRegistration
impl CSSRegistration
Sourcepub fn fonts_updated<F, Fut>(&self, callback: F)
pub fn fonts_updated<F, Fut>(&self, callback: F)
Fires whenever a web font is updated. A non-empty font parameter indicates a successfully loaded web font.
Sourcepub fn media_query_result_changed<F, Fut>(&self, callback: F)
pub fn media_query_result_changed<F, Fut>(&self, callback: F)
Fires whenever a MediaQuery result changes (for example, after a browser window has been resized.) The current implementation considers only viewport-dependent media features.
Sourcepub fn style_sheet_added<F, Fut>(&self, callback: F)
pub fn style_sheet_added<F, Fut>(&self, callback: F)
Fired whenever an active document stylesheet is added.
Sourcepub fn style_sheet_changed<F, Fut>(&self, callback: F)
pub fn style_sheet_changed<F, Fut>(&self, callback: F)
Fired whenever a stylesheet is changed as a result of the client operation.
Sourcepub fn style_sheet_removed<F, Fut>(&self, callback: F)
pub fn style_sheet_removed<F, Fut>(&self, callback: F)
Fired whenever an active document stylesheet is removed.
pub fn computed_style_updated<F, Fut>(&self, callback: F)