pub struct DebuggerRegistration { /* private fields */ }Expand description
Event registration interface for Debugger domain.
Implementations
Sourceimpl DebuggerRegistration
impl DebuggerRegistration
Sourcepub fn breakpoint_resolved<F, Fut>(&self, callback: F)
pub fn breakpoint_resolved<F, Fut>(&self, callback: F)
Fired when breakpoint is resolved to an actual script and location.
Deprecated in favor of resolvedBreakpoints in the scriptParsed event.
Sourcepub fn paused<F, Fut>(&self, callback: F)
pub fn paused<F, Fut>(&self, callback: F)
Fired when the virtual machine stopped on breakpoint or exception or any other stop criteria.
Sourcepub fn script_failed_to_parse<F, Fut>(&self, callback: F)
pub fn script_failed_to_parse<F, Fut>(&self, callback: F)
Fired when virtual machine fails to parse the script.
Sourcepub fn script_parsed<F, Fut>(&self, callback: F)
pub fn script_parsed<F, Fut>(&self, callback: F)
Fired when virtual machine parses script. This event is also fired for all known and uncollected scripts upon enabling debugger.