DOMRegistration

Struct DOMRegistration 

pub struct DOMRegistration { /* private fields */ }
Event registration interface for DOM domain.

Implementations

Source

impl DOMRegistration

pub fn attribute_modified<F, Fut>(&self, callback: F)
where F: Fn(AttributeModifiedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Element’s attribute is modified.

pub fn adopted_style_sheets_modified<F, Fut>(&self, callback: F)
where F: Fn(AdoptedStyleSheetsModifiedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Element’s adoptedStyleSheets are modified.

pub fn attribute_removed<F, Fut>(&self, callback: F)
where F: Fn(AttributeRemovedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Element’s attribute is removed.

pub fn character_data_modified<F, Fut>(&self, callback: F)
where F: Fn(CharacterDataModifiedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Mirrors DOMCharacterDataModified event.

pub fn child_node_count_updated<F, Fut>(&self, callback: F)
where F: Fn(ChildNodeCountUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Container’s child node count has changed.

pub fn child_node_inserted<F, Fut>(&self, callback: F)
where F: Fn(ChildNodeInsertedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Mirrors DOMNodeInserted event.

pub fn child_node_removed<F, Fut>(&self, callback: F)
where F: Fn(ChildNodeRemovedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Mirrors DOMNodeRemoved event.

pub fn distributed_nodes_updated<F, Fut>(&self, callback: F)
where F: Fn(DistributedNodesUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when distribution is changed.

pub fn document_updated<F, Fut>(&self, callback: F)
where F: Fn(DocumentUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Document has been totally updated. Node ids are no longer valid.

pub fn inline_style_invalidated<F, Fut>(&self, callback: F)
where F: Fn(InlineStyleInvalidatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when Element’s inline style is modified via a CSS property modification.

pub fn pseudo_element_added<F, Fut>(&self, callback: F)
where F: Fn(PseudoElementAddedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when a pseudo element is added to an element.

pub fn top_layer_elements_updated<F, Fut>(&self, callback: F)
where F: Fn(TopLayerElementsUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when top layer elements are changed.

pub fn scrollable_flag_updated<F, Fut>(&self, callback: F)
where F: Fn(ScrollableFlagUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when a node’s scrollability state changes.

pub fn affected_by_starting_styles_flag_updated<F, Fut>(&self, callback: F)
where F: Fn(AffectedByStartingStylesFlagUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when a node’s starting styles changes.

pub fn pseudo_element_removed<F, Fut>(&self, callback: F)
where F: Fn(PseudoElementRemovedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when a pseudo element is removed from an element.

pub fn set_child_nodes<F, Fut>(&self, callback: F)
where F: Fn(SetChildNodesEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids.

pub fn shadow_root_popped<F, Fut>(&self, callback: F)
where F: Fn(ShadowRootPoppedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when shadow root is popped from the element.

pub fn shadow_root_pushed<F, Fut>(&self, callback: F)
where F: Fn(ShadowRootPushedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Called when shadow root is pushed into the element.