DOMStorageClient

Struct DOMStorageClient 

pub struct DOMStorageClient { /* private fields */ }
Client for DOMStorage domain commands.

Implementations

Source

impl DOMStorageClient

pub async fn clear( &self, params: ClearParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Disables storage tracking, prevents storage events from being sent to the client.

pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Enables storage tracking, storage events will now be delivered to the client.

pub async fn get_dom_storage_items( &self, params: GetDomStorageItemsParams, session_id: Option<&str>, ) -> Result<GetDomStorageItemsReturns, CdpError>

pub async fn remove_dom_storage_item( &self, params: RemoveDomStorageItemParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

pub async fn set_dom_storage_item( &self, params: SetDomStorageItemParams, session_id: Option<&str>, ) -> Result<Value, CdpError>