FetchRegistration

Struct FetchRegistration 

pub struct FetchRegistration { /* private fields */ }
Event registration interface for Fetch domain.

Implementations

Source

impl FetchRegistration

pub fn request_paused<F, Fut>(&self, callback: F)
where F: Fn(RequestPausedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Issued when the domain is enabled and the request URL matches the specified filter. The request is paused until the client responds with one of continueRequest, failRequest or fulfillRequest. The stage of the request can be determined by presence of responseErrorReason and responseStatusCode – the request is at the response stage if either of these fields is present and in the request stage otherwise. Redirect responses and subsequent requests are reported similarly to regular responses and requests. Redirect responses may be distinguished by the value of responseStatusCode (which is one of 301, 302, 303, 307, 308) along with presence of the location header. Requests resulting from a redirect will have redirectedRequestId field set.

pub fn auth_required<F, Fut>(&self, callback: F)
where F: Fn(AuthRequiredEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Issued when the domain is enabled with handleAuthRequests set to true. The request is paused until client responds with continueWithAuth.