LayerTreeClient

Struct LayerTreeClient 

pub struct LayerTreeClient { /* private fields */ }
Client for LayerTree domain commands.

Implementations

Source

impl LayerTreeClient

pub async fn compositing_reasons( &self, params: CompositingReasonsParams, session_id: Option<&str>, ) -> Result<CompositingReasonsReturns, CdpError>

Provides the reasons why the given layer was composited.

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Disables compositing tree inspection.

pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Enables compositing tree inspection.

pub async fn load_snapshot( &self, params: LoadSnapshotParams, session_id: Option<&str>, ) -> Result<LoadSnapshotReturns, CdpError>

Returns the snapshot identifier.

pub async fn make_snapshot( &self, params: MakeSnapshotParams, session_id: Option<&str>, ) -> Result<MakeSnapshotReturns, CdpError>

Returns the layer snapshot identifier.

pub async fn profile_snapshot( &self, params: ProfileSnapshotParams, session_id: Option<&str>, ) -> Result<ProfileSnapshotReturns, CdpError>

pub async fn release_snapshot( &self, params: ReleaseSnapshotParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Releases layer snapshot captured by the back-end.

pub async fn replay_snapshot( &self, params: ReplaySnapshotParams, session_id: Option<&str>, ) -> Result<ReplaySnapshotReturns, CdpError>

Replays the layer snapshot and returns the resulting bitmap.

pub async fn snapshot_command_log( &self, params: SnapshotCommandLogParams, session_id: Option<&str>, ) -> Result<SnapshotCommandLogReturns, CdpError>

Replays the layer snapshot and returns canvas log.