pub struct LogClient { /* private fields */ }Expand description
Client for Log domain commands.
Implementations
Sourceimpl LogClient
impl LogClient
Sourcepub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Disables log domain, prevents further log entries from being reported to the client.
Sourcepub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Enables log domain, sends the entries collected so far to the client by means of the
entryAdded notification.
Sourcepub async fn start_violations_report(
&self,
params: StartViolationsReportParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn start_violations_report( &self, params: StartViolationsReportParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
start violation reporting.