MemoryClient

Struct MemoryClient 

pub struct MemoryClient { /* private fields */ }
Client for Memory domain commands.

Implementations

Source

impl MemoryClient

pub async fn get_dom_counters( &self, session_id: Option<&str>, ) -> Result<GetDomCountersReturns, CdpError>

Retruns current DOM object counters.

pub async fn get_dom_counters_for_leak_detection( &self, session_id: Option<&str>, ) -> Result<GetDomCountersForLeakDetectionReturns, CdpError>

Retruns DOM object counters after preparing renderer for leak detection.

pub async fn prepare_for_leak_detection( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>

Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc.

pub async fn forcibly_purge_java_script_memory( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulate OomIntervention by purging V8 memory.

pub async fn set_pressure_notifications_suppressed( &self, params: SetPressureNotificationsSuppressedParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enable/disable suppressing memory pressure notifications in all processes.

pub async fn simulate_pressure_notification( &self, params: SimulatePressureNotificationParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Simulate a memory pressure notification in all processes.

pub async fn start_sampling( &self, params: StartSamplingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Start collecting native memory profile.

pub async fn stop_sampling( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>

Stop collecting native memory profile.

pub async fn get_all_time_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetAllTimeSamplingProfileReturns, CdpError>

Retrieve native memory allocations profile collected since renderer process startup.

pub async fn get_browser_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetBrowserSamplingProfileReturns, CdpError>

Retrieve native memory allocations profile collected since browser process startup.

pub async fn get_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetSamplingProfileReturns, CdpError>

Retrieve native memory allocations profile collected since last startSampling call.