NetworkRegistration

Struct NetworkRegistration 

pub struct NetworkRegistration { /* private fields */ }
Event registration interface for Network domain.

Implementations

Source

impl NetworkRegistration

pub fn data_received<F, Fut>(&self, callback: F)
where F: Fn(DataReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when data chunk was received over the network.

pub fn event_source_message_received<F, Fut>(&self, callback: F)
where F: Fn(EventSourceMessageReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when EventSource message is received.

pub fn loading_failed<F, Fut>(&self, callback: F)
where F: Fn(LoadingFailedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when HTTP request has failed to load.

pub fn loading_finished<F, Fut>(&self, callback: F)
where F: Fn(LoadingFinishedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when HTTP request has finished loading.

pub fn request_intercepted<F, Fut>(&self, callback: F)
where F: Fn(RequestInterceptedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Details of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead.

pub fn request_served_from_cache<F, Fut>(&self, callback: F)
where F: Fn(RequestServedFromCacheEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired if request ended up loading from cache.

pub fn request_will_be_sent<F, Fut>(&self, callback: F)
where F: Fn(RequestWillBeSentEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when page is about to send HTTP request.

pub fn resource_changed_priority<F, Fut>(&self, callback: F)
where F: Fn(ResourceChangedPriorityEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when resource loading priority is changed

pub fn signed_exchange_received<F, Fut>(&self, callback: F)
where F: Fn(SignedExchangeReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when a signed exchange was received over the network

pub fn response_received<F, Fut>(&self, callback: F)
where F: Fn(ResponseReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when HTTP response is available.

pub fn web_socket_closed<F, Fut>(&self, callback: F)
where F: Fn(WebSocketClosedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket is closed.

pub fn web_socket_created<F, Fut>(&self, callback: F)
where F: Fn(WebSocketCreatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired upon WebSocket creation.

pub fn web_socket_frame_error<F, Fut>(&self, callback: F)
where F: Fn(WebSocketFrameErrorEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket message error occurs.

pub fn web_socket_frame_received<F, Fut>(&self, callback: F)
where F: Fn(WebSocketFrameReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket message is received.

pub fn web_socket_frame_sent<F, Fut>(&self, callback: F)
where F: Fn(WebSocketFrameSentEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket message is sent.

pub fn web_socket_handshake_response_received<F, Fut>(&self, callback: F)
where F: Fn(WebSocketHandshakeResponseReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket handshake response becomes available.

pub fn web_socket_will_send_handshake_request<F, Fut>(&self, callback: F)
where F: Fn(WebSocketWillSendHandshakeRequestEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebSocket is about to initiate handshake.

pub fn web_transport_created<F, Fut>(&self, callback: F)
where F: Fn(WebTransportCreatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired upon WebTransport creation.

pub fn web_transport_connection_established<F, Fut>(&self, callback: F)
where F: Fn(WebTransportConnectionEstablishedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebTransport handshake is finished.

pub fn web_transport_closed<F, Fut>(&self, callback: F)
where F: Fn(WebTransportClosedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when WebTransport is disposed.

pub fn direct_tcp_socket_created<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketCreatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired upon direct_socket.TCPSocket creation.

pub fn direct_tcp_socket_opened<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketOpenedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.TCPSocket connection is opened.

pub fn direct_tcp_socket_aborted<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketAbortedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.TCPSocket is aborted.

pub fn direct_tcp_socket_closed<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketClosedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.TCPSocket is closed.

pub fn direct_tcp_socket_chunk_sent<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketChunkSentEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when data is sent to tcp direct socket stream.

pub fn direct_tcp_socket_chunk_received<F, Fut>(&self, callback: F)
where F: Fn(DirectTcpSocketChunkReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when data is received from tcp direct socket stream.

pub fn direct_udp_socket_joined_multicast_group<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketJoinedMulticastGroupEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

pub fn direct_udp_socket_left_multicast_group<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketLeftMulticastGroupEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

pub fn direct_udp_socket_created<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketCreatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired upon direct_socket.UDPSocket creation.

pub fn direct_udp_socket_opened<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketOpenedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.UDPSocket connection is opened.

pub fn direct_udp_socket_aborted<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketAbortedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.UDPSocket is aborted.

pub fn direct_udp_socket_closed<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketClosedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when direct_socket.UDPSocket is closed.

pub fn direct_udp_socket_chunk_sent<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketChunkSentEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when message is sent to udp direct socket stream.

pub fn direct_udp_socket_chunk_received<F, Fut>(&self, callback: F)
where F: Fn(DirectUdpSocketChunkReceivedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when message is received from udp direct socket stream.

pub fn request_will_be_sent_extra_info<F, Fut>(&self, callback: F)
where F: Fn(RequestWillBeSentExtraInfoEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request.

pub fn response_received_extra_info<F, Fut>(&self, callback: F)
where F: Fn(ResponseReceivedExtraInfoEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived.

pub fn response_received_early_hints<F, Fut>(&self, callback: F)
where F: Fn(ResponseReceivedEarlyHintsEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired when 103 Early Hints headers is received in addition to the common response. Not every responseReceived event will have an responseReceivedEarlyHints fired. Only one responseReceivedEarlyHints may be fired for eached responseReceived event.

pub fn trust_token_operation_done<F, Fut>(&self, callback: F)
where F: Fn(TrustTokenOperationDoneEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received.

pub fn policy_updated<F, Fut>(&self, callback: F)
where F: Fn(PolicyUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Fired once security policy has been updated.

pub fn reporting_api_report_added<F, Fut>(&self, callback: F)
where F: Fn(ReportingApiReportAddedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Is sent whenever a new report is added. And after ‘enableReportingApi’ for all existing reports.

pub fn reporting_api_report_updated<F, Fut>(&self, callback: F)
where F: Fn(ReportingApiReportUpdatedEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

pub fn reporting_api_endpoints_changed_for_origin<F, Fut>(&self, callback: F)
where F: Fn(ReportingApiEndpointsChangedForOriginEvent, Option<String>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,