PerformanceClient

Struct PerformanceClient 

pub struct PerformanceClient { /* private fields */ }
Client for Performance domain commands.

Implementations

Source

impl PerformanceClient

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Disable collecting and reporting metrics.

pub async fn enable( &self, params: EnableParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enable collecting and reporting metrics.

pub async fn set_time_domain( &self, params: SetTimeDomainParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.

pub async fn get_metrics( &self, session_id: Option<&str>, ) -> Result<GetMetricsReturns, CdpError>

Retrieve current values of run-time metrics.