ProfilerClient

Struct ProfilerClient 

pub struct ProfilerClient { /* private fields */ }
Client for Profiler domain commands.

Implementations

Source

impl ProfilerClient

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

pub async fn get_best_effort_coverage( &self, session_id: Option<&str>, ) -> Result<GetBestEffortCoverageReturns, CdpError>

Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.

pub async fn set_sampling_interval( &self, params: SetSamplingIntervalParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.

pub async fn start(&self, session_id: Option<&str>) -> Result<Value, CdpError>

pub async fn start_precise_coverage( &self, params: StartPreciseCoverageParams, session_id: Option<&str>, ) -> Result<StartPreciseCoverageReturns, CdpError>

Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.

pub async fn stop( &self, session_id: Option<&str>, ) -> Result<StopReturns, CdpError>

pub async fn stop_precise_coverage( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>

Disable precise code coverage. Disabling releases unnecessary execution count records and allows executing optimized code.

pub async fn take_precise_coverage( &self, session_id: Option<&str>, ) -> Result<TakePreciseCoverageReturns, CdpError>

Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.