StorageClient

Struct StorageClient 

pub struct StorageClient { /* private fields */ }
Client for Storage domain commands.

Implementations

Source

impl StorageClient

pub async fn get_storage_key_for_frame( &self, params: GetStorageKeyForFrameParams, session_id: Option<&str>, ) -> Result<GetStorageKeyForFrameReturns, CdpError>

Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.

pub async fn get_storage_key( &self, params: GetStorageKeyParams, session_id: Option<&str>, ) -> Result<GetStorageKeyReturns, CdpError>

Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.

pub async fn clear_data_for_origin( &self, params: ClearDataForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Clears storage for origin.

pub async fn clear_data_for_storage_key( &self, params: ClearDataForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Clears storage for storage key.

pub async fn get_cookies( &self, params: GetCookiesParams, session_id: Option<&str>, ) -> Result<GetCookiesReturns, CdpError>

Returns all browser cookies.

pub async fn set_cookies( &self, params: SetCookiesParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets given cookies.

pub async fn clear_cookies( &self, params: ClearCookiesParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Clears cookies.

pub async fn get_usage_and_quota( &self, params: GetUsageAndQuotaParams, session_id: Option<&str>, ) -> Result<GetUsageAndQuotaReturns, CdpError>

Returns usage and quota in bytes.

pub async fn override_quota_for_origin( &self, params: OverrideQuotaForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Override quota for the specified origin

pub async fn track_cache_storage_for_origin( &self, params: TrackCacheStorageForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Registers origin to be notified when an update occurs to its cache storage list.

pub async fn track_cache_storage_for_storage_key( &self, params: TrackCacheStorageForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Registers storage key to be notified when an update occurs to its cache storage list.

pub async fn track_indexed_db_for_origin( &self, params: TrackIndexedDbForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Registers origin to be notified when an update occurs to its IndexedDB.

pub async fn track_indexed_db_for_storage_key( &self, params: TrackIndexedDbForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Registers storage key to be notified when an update occurs to its IndexedDB.

pub async fn untrack_cache_storage_for_origin( &self, params: UntrackCacheStorageForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Unregisters origin from receiving notifications for cache storage.

pub async fn untrack_cache_storage_for_storage_key( &self, params: UntrackCacheStorageForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Unregisters storage key from receiving notifications for cache storage.

pub async fn untrack_indexed_db_for_origin( &self, params: UntrackIndexedDbForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Unregisters origin from receiving notifications for IndexedDB.

pub async fn untrack_indexed_db_for_storage_key( &self, params: UntrackIndexedDbForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Unregisters storage key from receiving notifications for IndexedDB.

pub async fn get_trust_tokens( &self, session_id: Option<&str>, ) -> Result<GetTrustTokensReturns, CdpError>

Returns the number of stored Trust Tokens per issuer for the current browsing context.

pub async fn clear_trust_tokens( &self, params: ClearTrustTokensParams, session_id: Option<&str>, ) -> Result<ClearTrustTokensReturns, CdpError>

Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.

pub async fn get_interest_group_details( &self, params: GetInterestGroupDetailsParams, session_id: Option<&str>, ) -> Result<GetInterestGroupDetailsReturns, CdpError>

Gets details for a named interest group.

pub async fn set_interest_group_tracking( &self, params: SetInterestGroupTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enables/Disables issuing of interestGroupAccessed events.

pub async fn set_interest_group_auction_tracking( &self, params: SetInterestGroupAuctionTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enables/Disables issuing of interestGroupAuctionEventOccurred and interestGroupAuctionNetworkRequestCreated.

pub async fn get_shared_storage_metadata( &self, params: GetSharedStorageMetadataParams, session_id: Option<&str>, ) -> Result<GetSharedStorageMetadataReturns, CdpError>

Gets metadata for an origin’s shared storage.

pub async fn get_shared_storage_entries( &self, params: GetSharedStorageEntriesParams, session_id: Option<&str>, ) -> Result<GetSharedStorageEntriesReturns, CdpError>

Gets the entries in an given origin’s shared storage.

pub async fn set_shared_storage_entry( &self, params: SetSharedStorageEntryParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets entry with key and value for a given origin’s shared storage.

pub async fn delete_shared_storage_entry( &self, params: DeleteSharedStorageEntryParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Deletes entry for key (if it exists) for a given origin’s shared storage.

pub async fn clear_shared_storage_entries( &self, params: ClearSharedStorageEntriesParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Clears all entries for a given origin’s shared storage.

pub async fn reset_shared_storage_budget( &self, params: ResetSharedStorageBudgetParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Resets the budget for ownerOrigin by clearing all budget withdrawals.

pub async fn set_shared_storage_tracking( &self, params: SetSharedStorageTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enables/disables issuing of sharedStorageAccessed events.

pub async fn set_storage_bucket_tracking( &self, params: SetStorageBucketTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Set tracking for a storage key’s buckets.

pub async fn delete_storage_bucket( &self, params: DeleteStorageBucketParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Deletes the Storage Bucket with the given storage key and bucket name.

pub async fn run_bounce_tracking_mitigations( &self, session_id: Option<&str>, ) -> Result<RunBounceTrackingMitigationsReturns, CdpError>

Deletes state for sites identified as potential bounce trackers, immediately.

pub async fn set_attribution_reporting_local_testing_mode( &self, params: SetAttributionReportingLocalTestingModeParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

pub async fn set_attribution_reporting_tracking( &self, params: SetAttributionReportingTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enables/disables issuing of Attribution Reporting events.

pub async fn send_pending_attribution_reports( &self, session_id: Option<&str>, ) -> Result<SendPendingAttributionReportsReturns, CdpError>

Sends all pending Attribution Reports immediately, regardless of their scheduled report time.

Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.

Returns the list of URLs from a page and its embedded resources that match existing grace period URL pattern rules. https://developers.google.com/privacy-sandbox/cookies/temporary-exceptions/grace-period

pub async fn set_protected_audience_k_anonymity( &self, params: SetProtectedAudienceKAnonymityParams, session_id: Option<&str>, ) -> Result<Value, CdpError>