pub struct TargetRegistration { /* private fields */ }Expand description
Event registration interface for Target domain.
Implementations
Sourceimpl TargetRegistration
impl TargetRegistration
Sourcepub fn attached_to_target<F, Fut>(&self, callback: F)
pub fn attached_to_target<F, Fut>(&self, callback: F)
Issued when attached to target because of auto-attach or attachToTarget command.
Sourcepub fn detached_from_target<F, Fut>(&self, callback: F)
pub fn detached_from_target<F, Fut>(&self, callback: F)
Issued when detached from target for any reason (including detachFromTarget command). Can be
issued multiple times per target if multiple sessions have been attached to it.
Sourcepub fn received_message_from_target<F, Fut>(&self, callback: F)
pub fn received_message_from_target<F, Fut>(&self, callback: F)
Notifies about a new protocol message received from the session (as reported in
attachedToTarget event).
Sourcepub fn target_created<F, Fut>(&self, callback: F)
pub fn target_created<F, Fut>(&self, callback: F)
Issued when a possible inspection target is created.
Sourcepub fn target_destroyed<F, Fut>(&self, callback: F)
pub fn target_destroyed<F, Fut>(&self, callback: F)
Issued when a target is destroyed.
Sourcepub fn target_crashed<F, Fut>(&self, callback: F)
pub fn target_crashed<F, Fut>(&self, callback: F)
Issued when a target has crashed.
Sourcepub fn target_info_changed<F, Fut>(&self, callback: F)
pub fn target_info_changed<F, Fut>(&self, callback: F)
Issued when some information about a target has changed. This only happens between
targetCreated and targetDestroyed.