WebAuthnClient

Struct WebAuthnClient 

pub struct WebAuthnClient { /* private fields */ }
Client for WebAuthn domain commands.

Implementations

Source

impl WebAuthnClient

pub async fn enable( &self, params: EnableParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator.

pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>

Disable the WebAuthn domain.

pub async fn add_virtual_authenticator( &self, params: AddVirtualAuthenticatorParams, session_id: Option<&str>, ) -> Result<AddVirtualAuthenticatorReturns, CdpError>

Creates and adds a virtual authenticator.

pub async fn set_response_override_bits( &self, params: SetResponseOverrideBitsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.

pub async fn remove_virtual_authenticator( &self, params: RemoveVirtualAuthenticatorParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Removes the given authenticator.

pub async fn add_credential( &self, params: AddCredentialParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Adds the credential to the specified authenticator.

pub async fn get_credential( &self, params: GetCredentialParams, session_id: Option<&str>, ) -> Result<GetCredentialReturns, CdpError>

Returns a single credential stored in the given virtual authenticator that matches the credential ID.

pub async fn get_credentials( &self, params: GetCredentialsParams, session_id: Option<&str>, ) -> Result<GetCredentialsReturns, CdpError>

Returns all the credentials stored in the given virtual authenticator.

pub async fn remove_credential( &self, params: RemoveCredentialParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Removes a credential from the authenticator.

pub async fn clear_credentials( &self, params: ClearCredentialsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Clears all the credentials from the specified device.

pub async fn set_user_verified( &self, params: SetUserVerifiedParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets whether User Verification succeeds or fails for an authenticator. The default is true.

pub async fn set_automatic_presence_simulation( &self, params: SetAutomaticPresenceSimulationParams, session_id: Option<&str>, ) -> Result<Value, CdpError>

Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true.

pub async fn set_credential_properties( &self, params: SetCredentialPropertiesParams, session_id: Option<&str>, ) -> Result<Value, CdpError>