pub struct SetScriptSourceReturns {
pub call_frames: Option<Vec<CallFrame>>,
pub stack_changed: Option<bool>,
pub async_stack_trace: Option<StackTrace>,
pub async_stack_trace_id: Option<StackTraceId>,
pub status: String,
pub exception_details: Option<ExceptionDetails>,
}Expand description
Return type for Debugger.setScriptSource.
Fields
call_frames: Option<Vec<CallFrame>>New stack trace in case editing has happened while VM was stopped.
stack_changed: Option<bool>Whether current call stack was modified after applying the changes.
async_stack_trace: Option<StackTrace>Async stack trace, if any.
async_stack_trace_id: Option<StackTraceId>Async stack trace, if any.
status: StringWhether the operation was successful or not. Only Ok denotes a
successful live edit while the other enum variants denote why
the live edit failed.
exception_details: Option<ExceptionDetails>Exception details if any. Only present when status is CompileError.