pub struct DOMRegistration { /* private fields */ }Expand description
Event registration interface for DOM domain.
Implementations
Sourceimpl DOMRegistration
impl DOMRegistration
Sourcepub fn attribute_modified<F, Fut>(&self, callback: F)
pub fn attribute_modified<F, Fut>(&self, callback: F)
Fired when Element’s attribute is modified.
Sourcepub fn adopted_style_sheets_modified<F, Fut>(&self, callback: F)
pub fn adopted_style_sheets_modified<F, Fut>(&self, callback: F)
Fired when Element’s adoptedStyleSheets are modified.
Sourcepub fn attribute_removed<F, Fut>(&self, callback: F)
pub fn attribute_removed<F, Fut>(&self, callback: F)
Fired when Element’s attribute is removed.
Sourcepub fn character_data_modified<F, Fut>(&self, callback: F)
pub fn character_data_modified<F, Fut>(&self, callback: F)
Mirrors DOMCharacterDataModified event.
Sourcepub fn child_node_count_updated<F, Fut>(&self, callback: F)
pub fn child_node_count_updated<F, Fut>(&self, callback: F)
Fired when Container’s child node count has changed.
Sourcepub fn child_node_inserted<F, Fut>(&self, callback: F)
pub fn child_node_inserted<F, Fut>(&self, callback: F)
Mirrors DOMNodeInserted event.
Sourcepub fn child_node_removed<F, Fut>(&self, callback: F)
pub fn child_node_removed<F, Fut>(&self, callback: F)
Mirrors DOMNodeRemoved event.
Sourcepub fn distributed_nodes_updated<F, Fut>(&self, callback: F)
pub fn distributed_nodes_updated<F, Fut>(&self, callback: F)
Called when distribution is changed.
Sourcepub fn document_updated<F, Fut>(&self, callback: F)
pub fn document_updated<F, Fut>(&self, callback: F)
Fired when Document has been totally updated. Node ids are no longer valid.
Sourcepub fn inline_style_invalidated<F, Fut>(&self, callback: F)
pub fn inline_style_invalidated<F, Fut>(&self, callback: F)
Fired when Element’s inline style is modified via a CSS property modification.
Sourcepub fn pseudo_element_added<F, Fut>(&self, callback: F)
pub fn pseudo_element_added<F, Fut>(&self, callback: F)
Called when a pseudo element is added to an element.
Sourcepub fn top_layer_elements_updated<F, Fut>(&self, callback: F)
pub fn top_layer_elements_updated<F, Fut>(&self, callback: F)
Called when top layer elements are changed.
Sourcepub fn scrollable_flag_updated<F, Fut>(&self, callback: F)
pub fn scrollable_flag_updated<F, Fut>(&self, callback: F)
Fired when a node’s scrollability state changes.
Sourcepub fn affected_by_starting_styles_flag_updated<F, Fut>(&self, callback: F)
pub fn affected_by_starting_styles_flag_updated<F, Fut>(&self, callback: F)
Fired when a node’s starting styles changes.
Sourcepub fn pseudo_element_removed<F, Fut>(&self, callback: F)
pub fn pseudo_element_removed<F, Fut>(&self, callback: F)
Called when a pseudo element is removed from an element.
Sourcepub fn set_child_nodes<F, Fut>(&self, callback: F)
pub fn set_child_nodes<F, Fut>(&self, callback: F)
Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids.
Sourcepub fn shadow_root_popped<F, Fut>(&self, callback: F)
pub fn shadow_root_popped<F, Fut>(&self, callback: F)
Called when shadow root is popped from the element.