pub struct ExtensionsClient { /* private fields */ }Expand description
Client for Extensions domain commands.
Implementations
Sourceimpl ExtensionsClient
impl ExtensionsClient
Sourcepub async fn load_unpacked(
&self,
params: LoadUnpackedParams,
session_id: Option<&str>,
) -> Result<LoadUnpackedReturns, CdpError>
pub async fn load_unpacked( &self, params: LoadUnpackedParams, session_id: Option<&str>, ) -> Result<LoadUnpackedReturns, CdpError>
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
Sourcepub async fn uninstall(
&self,
params: UninstallParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn uninstall( &self, params: UninstallParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging.
Sourcepub async fn get_storage_items(
&self,
params: GetStorageItemsParams,
session_id: Option<&str>,
) -> Result<GetStorageItemsReturns, CdpError>
pub async fn get_storage_items( &self, params: GetStorageItemsParams, session_id: Option<&str>, ) -> Result<GetStorageItemsReturns, CdpError>
Gets data from extension storage in the given storageArea. If keys is
specified, these are used to filter the result.
Sourcepub async fn remove_storage_items(
&self,
params: RemoveStorageItemsParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn remove_storage_items( &self, params: RemoveStorageItemsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Removes keys from extension storage in the given storageArea.
Sourcepub async fn clear_storage_items(
&self,
params: ClearStorageItemsParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn clear_storage_items( &self, params: ClearStorageItemsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Clears extension storage in the given storageArea.
Sourcepub async fn set_storage_items(
&self,
params: SetStorageItemsParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_storage_items( &self, params: SetStorageItemsParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Sets values in extension storage in the given storageArea. The provided values
will be merged with existing values in the storage area.