pub struct FetchClient { /* private fields */ }Expand description
Client for Fetch domain commands.
Implementations
Sourceimpl FetchClient
impl FetchClient
Sourcepub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Disables the fetch domain.
Sourcepub async fn enable(
&self,
params: EnableParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn enable( &self, params: EnableParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
Sourcepub async fn fail_request(
&self,
params: FailRequestParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn fail_request( &self, params: FailRequestParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Causes the request to fail with specified reason.
Sourcepub async fn fulfill_request(
&self,
params: FulfillRequestParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn fulfill_request( &self, params: FulfillRequestParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Provides response to the request.
Sourcepub async fn continue_request(
&self,
params: ContinueRequestParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn continue_request( &self, params: ContinueRequestParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Continues the request, optionally modifying some of its parameters.
Sourcepub async fn continue_with_auth(
&self,
params: ContinueWithAuthParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn continue_with_auth( &self, params: ContinueWithAuthParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Continues a request supplying authChallengeResponse following authRequired event.
Sourcepub async fn continue_response(
&self,
params: ContinueResponseParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn continue_response( &self, params: ContinueResponseParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
Sourcepub async fn get_response_body(
&self,
params: GetResponseBodyParams,
session_id: Option<&str>,
) -> Result<GetResponseBodyReturns, CdpError>
pub async fn get_response_body( &self, params: GetResponseBodyParams, session_id: Option<&str>, ) -> Result<GetResponseBodyReturns, CdpError>
Causes the body of the response to be received from the server and
returned as a single string. May only be issued for a request that
is paused in the Response stage and is mutually exclusive with
takeResponseBodyForInterceptionAsStream. Calling other methods that
affect the request or disabling fetch domain before body is received
results in an undefined behavior.
Note that the response body is not available for redirects. Requests
paused in the redirect received state may be differentiated by
responseCode and presence of location response header, see
comments to requestPaused for details.
Sourcepub async fn take_response_body_as_stream(
&self,
params: TakeResponseBodyAsStreamParams,
session_id: Option<&str>,
) -> Result<TakeResponseBodyAsStreamReturns, CdpError>
pub async fn take_response_body_as_stream( &self, params: TakeResponseBodyAsStreamParams, session_id: Option<&str>, ) -> Result<TakeResponseBodyAsStreamReturns, CdpError>
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.