pub struct LayerTreeClient { /* private fields */ }Expand description
Client for LayerTree domain commands.
Implementations
Sourceimpl LayerTreeClient
impl LayerTreeClient
Sourcepub async fn compositing_reasons(
&self,
params: CompositingReasonsParams,
session_id: Option<&str>,
) -> Result<CompositingReasonsReturns, CdpError>
pub async fn compositing_reasons( &self, params: CompositingReasonsParams, session_id: Option<&str>, ) -> Result<CompositingReasonsReturns, CdpError>
Provides the reasons why the given layer was composited.
Sourcepub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn disable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Disables compositing tree inspection.
Sourcepub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
pub async fn enable(&self, session_id: Option<&str>) -> Result<Value, CdpError>
Enables compositing tree inspection.
Sourcepub async fn load_snapshot(
&self,
params: LoadSnapshotParams,
session_id: Option<&str>,
) -> Result<LoadSnapshotReturns, CdpError>
pub async fn load_snapshot( &self, params: LoadSnapshotParams, session_id: Option<&str>, ) -> Result<LoadSnapshotReturns, CdpError>
Returns the snapshot identifier.
Sourcepub async fn make_snapshot(
&self,
params: MakeSnapshotParams,
session_id: Option<&str>,
) -> Result<MakeSnapshotReturns, CdpError>
pub async fn make_snapshot( &self, params: MakeSnapshotParams, session_id: Option<&str>, ) -> Result<MakeSnapshotReturns, CdpError>
Returns the layer snapshot identifier.
pub async fn profile_snapshot( &self, params: ProfileSnapshotParams, session_id: Option<&str>, ) -> Result<ProfileSnapshotReturns, CdpError>
Sourcepub async fn release_snapshot(
&self,
params: ReleaseSnapshotParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn release_snapshot( &self, params: ReleaseSnapshotParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Releases layer snapshot captured by the back-end.
Sourcepub async fn replay_snapshot(
&self,
params: ReplaySnapshotParams,
session_id: Option<&str>,
) -> Result<ReplaySnapshotReturns, CdpError>
pub async fn replay_snapshot( &self, params: ReplaySnapshotParams, session_id: Option<&str>, ) -> Result<ReplaySnapshotReturns, CdpError>
Replays the layer snapshot and returns the resulting bitmap.
Sourcepub async fn snapshot_command_log(
&self,
params: SnapshotCommandLogParams,
session_id: Option<&str>,
) -> Result<SnapshotCommandLogReturns, CdpError>
pub async fn snapshot_command_log( &self, params: SnapshotCommandLogParams, session_id: Option<&str>, ) -> Result<SnapshotCommandLogReturns, CdpError>
Replays the layer snapshot and returns canvas log.