pub struct MemoryClient { /* private fields */ }Expand description
Client for Memory domain commands.
Implementations
Sourceimpl MemoryClient
impl MemoryClient
Sourcepub async fn get_dom_counters(
&self,
session_id: Option<&str>,
) -> Result<GetDomCountersReturns, CdpError>
pub async fn get_dom_counters( &self, session_id: Option<&str>, ) -> Result<GetDomCountersReturns, CdpError>
Retruns current DOM object counters.
Sourcepub async fn get_dom_counters_for_leak_detection(
&self,
session_id: Option<&str>,
) -> Result<GetDomCountersForLeakDetectionReturns, CdpError>
pub async fn get_dom_counters_for_leak_detection( &self, session_id: Option<&str>, ) -> Result<GetDomCountersForLeakDetectionReturns, CdpError>
Retruns DOM object counters after preparing renderer for leak detection.
Sourcepub async fn prepare_for_leak_detection(
&self,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn prepare_for_leak_detection( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>
Prepares for leak detection by terminating workers, stopping spellcheckers, dropping non-essential internal caches, running garbage collections, etc.
Sourcepub async fn forcibly_purge_java_script_memory(
&self,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn forcibly_purge_java_script_memory( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>
Simulate OomIntervention by purging V8 memory.
Sourcepub async fn set_pressure_notifications_suppressed(
&self,
params: SetPressureNotificationsSuppressedParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_pressure_notifications_suppressed( &self, params: SetPressureNotificationsSuppressedParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Enable/disable suppressing memory pressure notifications in all processes.
Sourcepub async fn simulate_pressure_notification(
&self,
params: SimulatePressureNotificationParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn simulate_pressure_notification( &self, params: SimulatePressureNotificationParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Simulate a memory pressure notification in all processes.
Sourcepub async fn start_sampling(
&self,
params: StartSamplingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn start_sampling( &self, params: StartSamplingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Start collecting native memory profile.
Sourcepub async fn stop_sampling(
&self,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn stop_sampling( &self, session_id: Option<&str>, ) -> Result<Value, CdpError>
Stop collecting native memory profile.
Sourcepub async fn get_all_time_sampling_profile(
&self,
session_id: Option<&str>,
) -> Result<GetAllTimeSamplingProfileReturns, CdpError>
pub async fn get_all_time_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetAllTimeSamplingProfileReturns, CdpError>
Retrieve native memory allocations profile collected since renderer process startup.
Sourcepub async fn get_browser_sampling_profile(
&self,
session_id: Option<&str>,
) -> Result<GetBrowserSamplingProfileReturns, CdpError>
pub async fn get_browser_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetBrowserSamplingProfileReturns, CdpError>
Retrieve native memory allocations profile collected since browser process startup.
Sourcepub async fn get_sampling_profile(
&self,
session_id: Option<&str>,
) -> Result<GetSamplingProfileReturns, CdpError>
pub async fn get_sampling_profile( &self, session_id: Option<&str>, ) -> Result<GetSamplingProfileReturns, CdpError>
Retrieve native memory allocations profile collected since last
startSampling call.