pub struct NetworkRegistration { /* private fields */ }Expand description
Event registration interface for Network domain.
Implementations
Sourceimpl NetworkRegistration
impl NetworkRegistration
Sourcepub fn data_received<F, Fut>(&self, callback: F)
pub fn data_received<F, Fut>(&self, callback: F)
Fired when data chunk was received over the network.
Sourcepub fn event_source_message_received<F, Fut>(&self, callback: F)
pub fn event_source_message_received<F, Fut>(&self, callback: F)
Fired when EventSource message is received.
Sourcepub fn loading_failed<F, Fut>(&self, callback: F)
pub fn loading_failed<F, Fut>(&self, callback: F)
Fired when HTTP request has failed to load.
Sourcepub fn loading_finished<F, Fut>(&self, callback: F)
pub fn loading_finished<F, Fut>(&self, callback: F)
Fired when HTTP request has finished loading.
Sourcepub fn request_intercepted<F, Fut>(&self, callback: F)
pub fn request_intercepted<F, Fut>(&self, callback: F)
Details of an intercepted HTTP request, which must be either allowed, blocked, modified or mocked. Deprecated, use Fetch.requestPaused instead.
Sourcepub fn request_served_from_cache<F, Fut>(&self, callback: F)
pub fn request_served_from_cache<F, Fut>(&self, callback: F)
Fired if request ended up loading from cache.
Sourcepub fn request_will_be_sent<F, Fut>(&self, callback: F)
pub fn request_will_be_sent<F, Fut>(&self, callback: F)
Fired when page is about to send HTTP request.
Sourcepub fn resource_changed_priority<F, Fut>(&self, callback: F)
pub fn resource_changed_priority<F, Fut>(&self, callback: F)
Fired when resource loading priority is changed
Sourcepub fn signed_exchange_received<F, Fut>(&self, callback: F)
pub fn signed_exchange_received<F, Fut>(&self, callback: F)
Fired when a signed exchange was received over the network
Sourcepub fn response_received<F, Fut>(&self, callback: F)
pub fn response_received<F, Fut>(&self, callback: F)
Fired when HTTP response is available.
Sourcepub fn web_socket_closed<F, Fut>(&self, callback: F)
pub fn web_socket_closed<F, Fut>(&self, callback: F)
Fired when WebSocket is closed.
Sourcepub fn web_socket_created<F, Fut>(&self, callback: F)
pub fn web_socket_created<F, Fut>(&self, callback: F)
Fired upon WebSocket creation.
Sourcepub fn web_socket_frame_error<F, Fut>(&self, callback: F)
pub fn web_socket_frame_error<F, Fut>(&self, callback: F)
Fired when WebSocket message error occurs.
Sourcepub fn web_socket_frame_received<F, Fut>(&self, callback: F)
pub fn web_socket_frame_received<F, Fut>(&self, callback: F)
Fired when WebSocket message is received.
Sourcepub fn web_socket_frame_sent<F, Fut>(&self, callback: F)
pub fn web_socket_frame_sent<F, Fut>(&self, callback: F)
Fired when WebSocket message is sent.
Sourcepub fn web_socket_handshake_response_received<F, Fut>(&self, callback: F)
pub fn web_socket_handshake_response_received<F, Fut>(&self, callback: F)
Fired when WebSocket handshake response becomes available.
Sourcepub fn web_socket_will_send_handshake_request<F, Fut>(&self, callback: F)
pub fn web_socket_will_send_handshake_request<F, Fut>(&self, callback: F)
Fired when WebSocket is about to initiate handshake.
Sourcepub fn web_transport_created<F, Fut>(&self, callback: F)
pub fn web_transport_created<F, Fut>(&self, callback: F)
Fired upon WebTransport creation.
Sourcepub fn web_transport_connection_established<F, Fut>(&self, callback: F)
pub fn web_transport_connection_established<F, Fut>(&self, callback: F)
Fired when WebTransport handshake is finished.
Sourcepub fn web_transport_closed<F, Fut>(&self, callback: F)
pub fn web_transport_closed<F, Fut>(&self, callback: F)
Fired when WebTransport is disposed.
Sourcepub fn direct_tcp_socket_created<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_created<F, Fut>(&self, callback: F)
Fired upon direct_socket.TCPSocket creation.
Sourcepub fn direct_tcp_socket_opened<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_opened<F, Fut>(&self, callback: F)
Fired when direct_socket.TCPSocket connection is opened.
Sourcepub fn direct_tcp_socket_aborted<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_aborted<F, Fut>(&self, callback: F)
Fired when direct_socket.TCPSocket is aborted.
Sourcepub fn direct_tcp_socket_closed<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_closed<F, Fut>(&self, callback: F)
Fired when direct_socket.TCPSocket is closed.
Sourcepub fn direct_tcp_socket_chunk_sent<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_chunk_sent<F, Fut>(&self, callback: F)
Fired when data is sent to tcp direct socket stream.
Sourcepub fn direct_tcp_socket_chunk_received<F, Fut>(&self, callback: F)
pub fn direct_tcp_socket_chunk_received<F, Fut>(&self, callback: F)
Fired when data is received from tcp direct socket stream.
pub fn direct_udp_socket_joined_multicast_group<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_left_multicast_group<F, Fut>(&self, callback: F)
Sourcepub fn direct_udp_socket_created<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_created<F, Fut>(&self, callback: F)
Fired upon direct_socket.UDPSocket creation.
Sourcepub fn direct_udp_socket_opened<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_opened<F, Fut>(&self, callback: F)
Fired when direct_socket.UDPSocket connection is opened.
Sourcepub fn direct_udp_socket_aborted<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_aborted<F, Fut>(&self, callback: F)
Fired when direct_socket.UDPSocket is aborted.
Sourcepub fn direct_udp_socket_closed<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_closed<F, Fut>(&self, callback: F)
Fired when direct_socket.UDPSocket is closed.
Sourcepub fn direct_udp_socket_chunk_sent<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_chunk_sent<F, Fut>(&self, callback: F)
Fired when message is sent to udp direct socket stream.
Sourcepub fn direct_udp_socket_chunk_received<F, Fut>(&self, callback: F)
pub fn direct_udp_socket_chunk_received<F, Fut>(&self, callback: F)
Fired when message is received from udp direct socket stream.
Sourcepub fn request_will_be_sent_extra_info<F, Fut>(&self, callback: F)
pub fn request_will_be_sent_extra_info<F, Fut>(&self, callback: F)
Fired when additional information about a requestWillBeSent event is available from the network stack. Not every requestWillBeSent event will have an additional requestWillBeSentExtraInfo fired for it, and there is no guarantee whether requestWillBeSent or requestWillBeSentExtraInfo will be fired first for the same request.
Sourcepub fn response_received_extra_info<F, Fut>(&self, callback: F)
pub fn response_received_extra_info<F, Fut>(&self, callback: F)
Fired when additional information about a responseReceived event is available from the network stack. Not every responseReceived event will have an additional responseReceivedExtraInfo for it, and responseReceivedExtraInfo may be fired before or after responseReceived.
Sourcepub fn response_received_early_hints<F, Fut>(&self, callback: F)
pub fn response_received_early_hints<F, Fut>(&self, callback: F)
Fired when 103 Early Hints headers is received in addition to the common response. Not every responseReceived event will have an responseReceivedEarlyHints fired. Only one responseReceivedEarlyHints may be fired for eached responseReceived event.
Sourcepub fn trust_token_operation_done<F, Fut>(&self, callback: F)
pub fn trust_token_operation_done<F, Fut>(&self, callback: F)
Fired exactly once for each Trust Token operation. Depending on the type of the operation and whether the operation succeeded or failed, the event is fired before the corresponding request was sent or after the response was received.
Sourcepub fn policy_updated<F, Fut>(&self, callback: F)
pub fn policy_updated<F, Fut>(&self, callback: F)
Fired once security policy has been updated.
Sourcepub fn reporting_api_report_added<F, Fut>(&self, callback: F)
pub fn reporting_api_report_added<F, Fut>(&self, callback: F)
Is sent whenever a new report is added. And after ‘enableReportingApi’ for all existing reports.