pub struct StorageClient { /* private fields */ }Expand description
Client for Storage domain commands.
Implementations
Sourceimpl StorageClient
impl StorageClient
Sourcepub async fn get_storage_key_for_frame(
&self,
params: GetStorageKeyForFrameParams,
session_id: Option<&str>,
) -> Result<GetStorageKeyForFrameReturns, CdpError>
pub async fn get_storage_key_for_frame( &self, params: GetStorageKeyForFrameParams, session_id: Option<&str>, ) -> Result<GetStorageKeyForFrameReturns, CdpError>
Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
Sourcepub async fn get_storage_key(
&self,
params: GetStorageKeyParams,
session_id: Option<&str>,
) -> Result<GetStorageKeyReturns, CdpError>
pub async fn get_storage_key( &self, params: GetStorageKeyParams, session_id: Option<&str>, ) -> Result<GetStorageKeyReturns, CdpError>
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
Sourcepub async fn clear_data_for_origin(
&self,
params: ClearDataForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn clear_data_for_origin( &self, params: ClearDataForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Clears storage for origin.
Sourcepub async fn clear_data_for_storage_key(
&self,
params: ClearDataForStorageKeyParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn clear_data_for_storage_key( &self, params: ClearDataForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Clears storage for storage key.
Returns all browser cookies.
Sets given cookies.
Clears cookies.
Sourcepub async fn get_usage_and_quota(
&self,
params: GetUsageAndQuotaParams,
session_id: Option<&str>,
) -> Result<GetUsageAndQuotaReturns, CdpError>
pub async fn get_usage_and_quota( &self, params: GetUsageAndQuotaParams, session_id: Option<&str>, ) -> Result<GetUsageAndQuotaReturns, CdpError>
Returns usage and quota in bytes.
Sourcepub async fn override_quota_for_origin(
&self,
params: OverrideQuotaForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn override_quota_for_origin( &self, params: OverrideQuotaForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Override quota for the specified origin
Sourcepub async fn track_cache_storage_for_origin(
&self,
params: TrackCacheStorageForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn track_cache_storage_for_origin( &self, params: TrackCacheStorageForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Registers origin to be notified when an update occurs to its cache storage list.
Sourcepub async fn track_cache_storage_for_storage_key(
&self,
params: TrackCacheStorageForStorageKeyParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn track_cache_storage_for_storage_key( &self, params: TrackCacheStorageForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Registers storage key to be notified when an update occurs to its cache storage list.
Sourcepub async fn track_indexed_db_for_origin(
&self,
params: TrackIndexedDbForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn track_indexed_db_for_origin( &self, params: TrackIndexedDbForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Registers origin to be notified when an update occurs to its IndexedDB.
Sourcepub async fn track_indexed_db_for_storage_key(
&self,
params: TrackIndexedDbForStorageKeyParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn track_indexed_db_for_storage_key( &self, params: TrackIndexedDbForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Registers storage key to be notified when an update occurs to its IndexedDB.
Sourcepub async fn untrack_cache_storage_for_origin(
&self,
params: UntrackCacheStorageForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn untrack_cache_storage_for_origin( &self, params: UntrackCacheStorageForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Unregisters origin from receiving notifications for cache storage.
Sourcepub async fn untrack_cache_storage_for_storage_key(
&self,
params: UntrackCacheStorageForStorageKeyParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn untrack_cache_storage_for_storage_key( &self, params: UntrackCacheStorageForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Unregisters storage key from receiving notifications for cache storage.
Sourcepub async fn untrack_indexed_db_for_origin(
&self,
params: UntrackIndexedDbForOriginParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn untrack_indexed_db_for_origin( &self, params: UntrackIndexedDbForOriginParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Unregisters origin from receiving notifications for IndexedDB.
Sourcepub async fn untrack_indexed_db_for_storage_key(
&self,
params: UntrackIndexedDbForStorageKeyParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn untrack_indexed_db_for_storage_key( &self, params: UntrackIndexedDbForStorageKeyParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Unregisters storage key from receiving notifications for IndexedDB.
Sourcepub async fn get_trust_tokens(
&self,
session_id: Option<&str>,
) -> Result<GetTrustTokensReturns, CdpError>
pub async fn get_trust_tokens( &self, session_id: Option<&str>, ) -> Result<GetTrustTokensReturns, CdpError>
Returns the number of stored Trust Tokens per issuer for the current browsing context.
Sourcepub async fn clear_trust_tokens(
&self,
params: ClearTrustTokensParams,
session_id: Option<&str>,
) -> Result<ClearTrustTokensReturns, CdpError>
pub async fn clear_trust_tokens( &self, params: ClearTrustTokensParams, session_id: Option<&str>, ) -> Result<ClearTrustTokensReturns, CdpError>
Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
Sourcepub async fn get_interest_group_details(
&self,
params: GetInterestGroupDetailsParams,
session_id: Option<&str>,
) -> Result<GetInterestGroupDetailsReturns, CdpError>
pub async fn get_interest_group_details( &self, params: GetInterestGroupDetailsParams, session_id: Option<&str>, ) -> Result<GetInterestGroupDetailsReturns, CdpError>
Gets details for a named interest group.
Sourcepub async fn set_interest_group_tracking(
&self,
params: SetInterestGroupTrackingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_interest_group_tracking( &self, params: SetInterestGroupTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Enables/Disables issuing of interestGroupAccessed events.
Sourcepub async fn set_interest_group_auction_tracking(
&self,
params: SetInterestGroupAuctionTrackingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_interest_group_auction_tracking( &self, params: SetInterestGroupAuctionTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Enables/Disables issuing of interestGroupAuctionEventOccurred and interestGroupAuctionNetworkRequestCreated.
Gets metadata for an origin’s shared storage.
Gets the entries in an given origin’s shared storage.
Sets entry with key and value for a given origin’s shared storage.
Deletes entry for key (if it exists) for a given origin’s shared storage.
Clears all entries for a given origin’s shared storage.
Resets the budget for ownerOrigin by clearing all budget withdrawals.
Enables/disables issuing of sharedStorageAccessed events.
Sourcepub async fn set_storage_bucket_tracking(
&self,
params: SetStorageBucketTrackingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_storage_bucket_tracking( &self, params: SetStorageBucketTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Set tracking for a storage key’s buckets.
Sourcepub async fn delete_storage_bucket(
&self,
params: DeleteStorageBucketParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn delete_storage_bucket( &self, params: DeleteStorageBucketParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Deletes the Storage Bucket with the given storage key and bucket name.
Sourcepub async fn run_bounce_tracking_mitigations(
&self,
session_id: Option<&str>,
) -> Result<RunBounceTrackingMitigationsReturns, CdpError>
pub async fn run_bounce_tracking_mitigations( &self, session_id: Option<&str>, ) -> Result<RunBounceTrackingMitigationsReturns, CdpError>
Deletes state for sites identified as potential bounce trackers, immediately.
Sourcepub async fn set_attribution_reporting_local_testing_mode(
&self,
params: SetAttributionReportingLocalTestingModeParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_attribution_reporting_local_testing_mode( &self, params: SetAttributionReportingLocalTestingModeParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Sourcepub async fn set_attribution_reporting_tracking(
&self,
params: SetAttributionReportingTrackingParams,
session_id: Option<&str>,
) -> Result<Value, CdpError>
pub async fn set_attribution_reporting_tracking( &self, params: SetAttributionReportingTrackingParams, session_id: Option<&str>, ) -> Result<Value, CdpError>
Enables/disables issuing of Attribution Reporting events.
Sourcepub async fn send_pending_attribution_reports(
&self,
session_id: Option<&str>,
) -> Result<SendPendingAttributionReportsReturns, CdpError>
pub async fn send_pending_attribution_reports( &self, session_id: Option<&str>, ) -> Result<SendPendingAttributionReportsReturns, CdpError>
Sends all pending Attribution Reports immediately, regardless of their scheduled report time.
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
Returns the list of URLs from a page and its embedded resources that match existing grace period URL pattern rules. https://developers.google.com/privacy-sandbox/cookies/temporary-exceptions/grace-period